@@ -73,14 +73,16 @@ class MkapiPlugin(BasePlugin):
         config["docs_dir"] = root
         files_ = get_files(config)
         config["docs_dir"] = docs_dir
+        theme_name = config["theme"].name
 
         css = []
         js = []
         for file in files_:
             path = file.src_path.replace("\\", "/")
             if path.endswith(".css"):
-                files.append(file)
-                css.append(path)
+                if "common" in path or theme_name in path:
+                    files.append(file)
+                    css.append(path)
             elif path.endswith(".js"):
                 files.append(file)
                 js.append(path)
@@ -95,9 +97,6 @@ class MkapiPlugin(BasePlugin):
         config["extra_css"] = css + config["extra_css"]
         config["extra_javascript"] = js + config["extra_javascript"]
 
-        for file in files:
-            normalize_file(file, config)
-
         return files
 
     def on_page_markdown(self, markdown, page, config, files):
@@ -115,6 +114,12 @@ class MkapiPlugin(BasePlugin):
         page = self.pages[abs_src_path]
         return page.content(html)
 
+    def on_page_context(self, context, page, config, nav):
+        abs_src_path = page.file.abs_src_path
+        if abs_src_path in self.abs_api_paths:
+            clear_prefix(page.toc)
+        return context
+
     def on_serve(self, server, config, builder):
         for path in ["theme", "templates"]:
             root = os.path.join(os.path.dirname(mkapi.__file__), path)
@@ -123,15 +128,9 @@ class MkapiPlugin(BasePlugin):
         return server
 
 
-NORMALIZE_PATTERN = re.compile(r"(^|[\\/])\w*[0-9]+[._ ](.*?)")
-
-
-def normalize_file(file, config):
-    if file.dest_path.endswith(".html"):
-        file.dest_path = NORMALIZE_PATTERN.sub(r"\1\2", file.dest_path)
-        file.dest_path = file.dest_path.replace(" ", "_")
-        file.abs_dest_path = os.path.normpath(
-            os.path.join(config["site_dir"], file.dest_path)
-        )
-        file.url = NORMALIZE_PATTERN.sub(r"\1\2", file.url)
-        file.url = file.url.replace(" ", "_")
+def clear_prefix(toc):
+    for toc_item in toc:
+        if toc_item.level >= 2:
+            toc_item.title = toc_item.title.split(".")[-1]
+        clear_prefix(toc_item.children)
+    return
